fnss.topologies.simplemodels.star_topology — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »

# fnss.topologies.simplemodels.star_topology

`star_topology`(n)

  Return a star (a.k.a hub-and-spoke) topology of nodes

  The root (hub) node has id 0 while all leaf (spoke) nodes have id .

  Each node has the attribute type which can either be root (for node 0) or leaf for all other nodes

  Parameters: | n : int The number of leaf nodes
  Returns: | topology : A Topology object

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »